"""
Framework integration examples.
"""

# FastAPI Integration
from fastapi import FastAPI
from pyfed.integration.frameworks.fastapi import FastAPIIntegration
from pyfed.integration.config import IntegrationConfig

async def fastapi_example():
    """FastAPI integration example."""
    # Create config
    config = IntegrationConfig(
        domain="example.com",
        database_url="postgresql://user:pass@localhost/pyfed",
        redis_url="redis://localhost",
        media_path="uploads/",
        key_path="keys/"
    )

    # Initialize integration
    integration = FastAPIIntegration(config)
    await integration.initialize()

    app = integration.app

    # Add custom routes
    @app.get("/custom")
    async def custom_route():
        return {"message": "Custom route"}

    return app

# Django Integration
from django.urls import path
from pyfed.integration.frameworks.django import DjangoIntegration

# settings.py
PYFED_CONFIG = {
    'domain': 'example.com',
    'database_url': 'postgresql://user:pass@localhost/pyfed',
    'redis_url': 'redis://localhost',
    'media_path': 'uploads/',
    'key_path': 'keys/',
}

# urls.py
from django.urls import path, include

urlpatterns = [
    path('', include('pyfed.integration.frameworks.django.urls')),
]

# Flask Integration
from flask import Flask
from pyfed.integration.frameworks.flask import FlaskIntegration

def flask_example():
    """Flask integration example."""
    app = Flask(__name__)
    
    config = IntegrationConfig(
        domain="example.com",
        database_url="postgresql://user:pass@localhost/pyfed",
        redis_url="redis://localhost",
        media_path="uploads/",
        key_path="keys/"
    )

    integration = FlaskIntegration(config)
    integration.initialize()

    return app 