from setuptools import setup, find_packages

setup(
    name="pyfed",
    version="0.1.0",
    description="A comprehensive Python library for ActivityPub federation",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="PyFed Team",
    author_email="team@pyfed.org",
    url="https://github.com/pyfed/pyfed",
    package_dir={"": "src"},
    packages=find_packages(where="src"),
    python_requires=">=3.8",
    install_requires=[
        "cryptography>=3.4.7",
        "aiohttp>=3.8.0",
        "pydantic>=1.8.2",
        "sqlalchemy>=1.4.0",
        "aiosqlite>=0.17.0",
        "asyncpg>=0.25.0",
        "redis>=4.0.0",
        "beautifulsoup4>=4.9.3",
        "markdown>=3.3.4",
        "Pillow>=10.2.0",
        "python-magic>=0.4.27",
        "mutagen>=1.47.0",
        "pydub>=0.25.1",
        "numpy>=1.24.0",
        "blurhash>=1.1.4",
        "aioboto3>=12.3.0",
        "aiofiles>=24.1.0",
    ],
    extras_require={
        "fastapi": ["fastapi>=0.68.0", "uvicorn>=0.15.0"],
        "django": ["django>=3.2.0"],
        "flask": ["flask>=2.0.0"],
        "dev": [
            "pytest>=6.2.5",
            "pytest-asyncio>=0.15.1",
            "pytest-cov>=2.12.1",
            "black>=22.3.0",
            "isort>=5.10.1",
            "flake8>=4.0.1",
            "mypy>=0.950",
        ],
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Framework :: AsyncIO",
    ],
    keywords="activitypub federation fediverse social-network",
    project_urls={
        "Documentation": "https://pyfed.readthedocs.io/",
        "Source": "https://github.com/pyfed/pyfed",
        "Tracker": "https://github.com/pyfed/pyfed/issues",
    },
)